summaryrefslogtreecommitdiff
path: root/src/egl/main/eglsurface.h
diff options
context:
space:
mode:
authorChia-I Wu <olvaffe@gmail.com>2010-01-30 22:45:54 +0800
committerChia-I Wu <olvaffe@gmail.com>2010-01-30 22:57:18 +0800
commit00e1790f3230de550121591d611b47da299ae15c (patch)
treec4772bcf9cee8de57e7a21ef2810e561ee577a6e /src/egl/main/eglsurface.h
parent94cb321b5d246185abf71d89968d472a626f1a23 (diff)
egl: Rename Binding to CurrentContext in _EGLSurface.
A context can be bound to a surface just like it can be bound to a thread. CurrentContext is a more consistent name.
Diffstat (limited to 'src/egl/main/eglsurface.h')
-rw-r--r--src/egl/main/eglsurface.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/egl/main/eglsurface.h b/src/egl/main/eglsurface.h
index 4062b990fa..eee66f6d86 100644
--- a/src/egl/main/eglsurface.h
+++ b/src/egl/main/eglsurface.h
@@ -14,9 +14,8 @@ struct _egl_surface
/* A surface is a display resource */
_EGLResource Resource;
- /* The bound status of the surface */
- _EGLContext *Binding;
- EGLBoolean BoundToTexture;
+ /* The context that is currently bound to the surface */
+ _EGLContext *CurrentContext;
_EGLConfig *Config;
@@ -26,6 +25,9 @@ struct _egl_surface
EGLint MipmapTexture, MipmapLevel;
EGLint SwapInterval;
+ /* True if the surface is bound to an OpenGL ES texture */
+ EGLBoolean BoundToTexture;
+
/* If type == EGL_SCREEN_BIT: */
EGLint VisibleRefCount; /* number of screens I'm displayed on */
@@ -100,14 +102,12 @@ _eglCreatePbufferFromClientBuffer(_EGLDriver *drv, _EGLDisplay *dpy,
/**
- * Return true if the surface is bound to a thread.
- * A surface bound to a texutre is not considered bound by
- * this function.
+ * Return true if there is a context bound to the surface.
*/
static INLINE EGLBoolean
_eglIsSurfaceBound(_EGLSurface *surf)
{
- return (surf->Binding != NULL);
+ return (surf->CurrentContext != NULL);
}